@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.3.0'
+__version__ = 'v1.3.3'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
@@ -94,6 +94,7 @@ class TranslateJson(object):
         #print("enter group")
         leval = 0
         group_path = self.get_group_path(dpath)
+        #print(group_path)
         for i in group_path:
             leval += 1 
             if i not in self.history_group:
@@ -146,6 +147,7 @@ class TranslateJson(object):
     
     
     def get_addr(self, dpath):
+        #print(dpath)
         base_changed = 0
         block_path = dpath.split("registers")[0]
         base_addr = int(self.get_delem(self.js_dict, block_path, key='base_addr'), 16)
@@ -186,10 +188,18 @@ class TranslateJson(object):
             self.history_addrr = now_addr
             return hex(now_addr)
         if 'Offset' in self.get_delem(self.js_dict, dpath):
+            #print((self.history_offset))
+            #print('history: ', hex(self.history_offset))
             offset_addr = self.get_delem(self.js_dict, dpath, key='Offset')
             offset_addr = int(offset_addr,16)
-            now_addr =  self.history_offset + offset_addr
+            #now_addr =  self.history_offset + offset_addr
+            if group_path:
+                now_addr =  self.history_offset + offset_addr
+            else:
+                now_addr =  self.history_base + offset_addr
+            #print('offset: ', hex(offset_addr))
             self.history_addrr = now_addr
+            #print('now_addr: ', hex(now_addr))
             return hex(now_addr)
     
     def find_group_path(self, group, root_path):
@@ -272,8 +282,9 @@ class TranslateJson(object):
         return step_msg, scope_msg, total_msg
     
     
-    def get_reserve_fields(self, fields):
-        re_map = [[0,31]]
+    def get_reserve_fields(self, fields, bit_num):
+        bit_num = int(bit_num)
+        re_map = [[0, bit_num -1]]
         re_fields = []
         for f in fields:
             index_range = f['range']
@@ -328,10 +339,11 @@ class TranslateJson(object):
                 else:
                     break
 
-    def get_reset(self, reset):
+    def get_reset(self, reset, bit_num):
+        bit_num = int(bit_num)
         value = ''
-        for i in range(32):
-            value += str(reset[31-i])
+        for i in range(bit_num):
+            value += str(reset[bit_num -1 -i])
         tmp = hex(int(value, 2))[2:]
         #if tmp == '0':
         #    hex_value = "0x" + tmp
@@ -361,10 +373,10 @@ class TranslateJson(object):
                     fields[i], fields[j] = fields[j], fields[i]
 
     
-    def create_md3(self, dpath, lm):
+    def create_md3(self, dpath, lm, bit_num = 32):
         ls = libsvg.LibSVG()
         reset = {}
-        for k,v in enumerate("0"*32):
+        for k,v in enumerate("0"*bit_num):
             reset[k] = v
     
         is_group = 0
@@ -387,11 +399,11 @@ class TranslateJson(object):
         #self.xmind_md += '### ' + name + '\n' + '> ' + des + '\n'
         self.xmind_md += '### ' + name + '\n'
         fields = self.get_delem(self.js_dict, dpath, key = 'Fields')
-        reserve_fields = self.get_reserve_fields(fields)
+        reserve_fields = self.get_reserve_fields(fields, bit_num)
         fields.extend(reserve_fields)
         self.relist_fields(fields)
 
-        table = ls.create_blank_form()
+        table = ls.create_blank_form(bit_num)
         for f in fields:
             ls.add_line(table, f['range'])
         for f in fields:
@@ -399,7 +411,7 @@ class TranslateJson(object):
             self.add_reset(reset, f['range'], f['reset_value'])
         for f in fields:
             ls.add_name(table, f['range'], f['name'])
-        hex_reset = self.get_reset(reset)
+        hex_reset = self.get_reset(reset, bit_num)
         if is_group:
             st_addr = int(addr.split("+")[0], 16)
             self.show_group(lm, group_msg, name ,des, st_addr, hex_reset)
@@ -565,7 +577,9 @@ class TranslateJson(object):
                         if name != "RESERVED":
                             dpath = self.js_dpath[i]
                             fd.write('  * [' + name + ']('+ name + '.md)\n')
-                            self.create_md3(self.js_dpath[i], lm)
+                            bit_num = self.get_delem(self.js_dict, dpath.split('registers')[0], \
+                                    key = 'd_width')
+                            self.create_md3(self.js_dpath[i], lm, bit_num)
                     self.relist(self.all_reg_list)
                     self.create_all_reg_data(lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
@@ -591,10 +605,14 @@ class TranslateJson(object):
                     fd.write('* [寄存器列表](' + reg_list_path + ')\n')
                     fd.write('* [寄存器详细说明](' + reg_detail_path + ')\n')
                     for i in self.js_dpath:
+                        name = self.get_delem(self.js_dict, i, key = 'RegName' )
+                        #print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>")
+                        #print(name)
                         addr = self.get_addr(i)
                         self.path_addr_dict[i] = addr
                         name = self.get_delem(self.js_dict, i, key = 'RegName' )
                         #print(name, "(" + addr + ")")
+                        #print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>")
                     self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
                     for i in range(int(len(self.js_dpath))):
                         name = self.get_delem(self.js_dict, self.js_dpath[i], key = 'RegName' )
@@ -603,7 +621,9 @@ class TranslateJson(object):
                             dpath = self.js_dpath[i]
                             #md_path = os.path.join(path_msg, name + ".md")
                             #fd.write('  * [' + name + ']('+ md_path + ')\n')
-                            self.create_md3(self.js_dpath[i], lm)
+                            bit_num = self.get_delem(self.js_dict, dpath.split('registers')[0], \
+                                    key = 'd_width')
+                            self.create_md3(self.js_dpath[i], lm, bit_num)
                     self.relist(self.all_reg_list)
                     self.create_all_reg_data(lm)
                     gitlog = ''
@@ -632,11 +652,14 @@ class TranslateJson(object):
                 self.path_addr_dict[i] = self.get_addr(i)
             self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
             for i in self.js_dpath:
-                self.create_md3(i, lm)
+                bit_num = self.get_delem(self.js_dict, i.split('registers')[0], \
+                        key = 'd_width')
+                self.create_md3(i, lm, bit_num)
             self.relist(self.all_reg_list)
             self.create_all_reg_data(lm)
             self.data = "# 寄存器列表\n" + self.all_reg_data + "\n"\
-                    + "# 寄存器详细说明\n" + self.data.replace("#", "##")
+                    + "# 寄存器详细说明\n" + self.data
+            self.data = self.data.replace("\n#", "\n##")
             if self.output_xmind:
                 md_file = file_msg + '.md'
                 with open(md_file, 'w') as fd:
