@@ -8,13 +8,13 @@ class PreProcess(object):
         pass
 
     def start(self, json_file):
-        with open(json_file, 'r') as jf:
+        with open(json_file, 'rb') as jf:
             js_dict = json.load(jf)
         return js_dict
 
 if __name__ == "__main__":
     pp = PreProcess()
-    #js_dict = pp.start("aaa.json")
-    js_dict = pp.start("npu_register.json")
+    js_dict = pp.start("/home/wangshj/cas_module2.json")
     print(js_dict)
+    #js_dict = pp.start("npu_register.json")
 
